set tcl_libdir "$tcl_library"

proc uid { } {
  return "[lindex [split [lindex [exec -- id] 0] ()] 1]"
}

proc *install:version:extract {{filename ""}} {
  if {$filename != ""} {
    set fileID [open $filename r]
    gets $fileID nulldata
    gets $fileID version
    catch {close $fileID}
    if {[string match "# ini_version=*" $version]} {
      set version [lindex [split [lindex $version 1] =] 1]
      return "$version"
    }
  }
  return "-1"
}

proc *install:iniparse {args} {
  # extract version information from the current package
  set data_version [*install:version:extract ./iniparse.tcl]

  # make sure we are running as root before we do this..
  if {[uid] != "root"} {
    puts "*** this script must be run as the superuser"
    exit
  } else {
    set pkgPath "$args/iniparse$data_version"

    ##### BEWARE #####
    # these files/directories could be symlinks
    ##### BEWARE #####

    # this returns 1 if the directory doesnt exist
    if {[catch {file lstat $pkgPath ldata} out]} {
      file mkdir $pkgPath
      file copy -force AUTHORS ChangeLog iniparse.tcl $pkgPath
      file attributes $pkgPath -owner root -group root -permissions 0755

      pkg_mkIndex -nopkgrequire -direct -verbose $pkgPath *.tcl

      puts "*** install of iniparse $data_version complete!"
    } else {
      if {$ldata(type) == "link"} {
        puts stdout "*** WARNING: $pkgPath is a symbolic link."
        puts stdout "*** this could be EXTREMELY dangerous to your system."
        puts stdout "*** exiting... "
        exit
      }

      set installfiles "$pkgPath/AUTHORS $pkgPath/ChangeLog\
                        $pkgPath/iniparse.tcl"
      foreach file $installfiles {
        if {[file exists $file]} {
          file lstat $file ldata
          if {$ldata(type) == "link"} {
            puts stdout "*** WARNING: $file is a symbolic link."
            puts stdout "*** this could be EXTREMELY dangerous to your system."
            puts stdout "*** exiting... "
            exit
          }
        }
      }
      file mkdir $pkgPath
      file copy -force AUTHORS ChangeLog iniparse.tcl $pkgPath
      file attributes $pkgPath -owner root -group root -permissions 0755
      pkg_mkIndex -nopkgrequire -direct -verbose $pkgPath *.tcl
      puts "*** install of iniparse $data_version complete!"
    }
  }
}

*install:iniparse $tcl_libdir
